function [ kt ] = Flat_Stress_Step_Bending( Big_Thick, Small_Thick, Fillet )
%
%  This routine computes the stress concentration factor for an bending load
%  on a flat bar shaft with a thickness change.  Values are taken from
%  page 1032 Figure C-10 in Norton
%
%      Big_Thick = the larger thickness of the bar
%      Small_Thick = the smaller thickness of the bar
%      Fillet = the radius of the fillet at the step

Dt = [6.0 3.0 2.0 1.3 1.2 1.1 1.07 1.05 1.03 1.02 1.01]';
At = [.85979 .90720 .93232 .95880 .99590 1.01650 1.01990 1.02260 1.01660 .99528 .96689]';
bt = [-.35847 -.333333 -.30304 -.27269 -.23829 -.21548 -.20333 -.19156 -.17802 -.17013 -.15417]';

%  Compute the diameter ratio and then interpolate A and b from the tables

D = Big_Thick / Small_Thick;
A = interp1 (Dt, At, D);
b = interp1 (Dt, bt, D);

%  Compute the stress concentration factor

kt = A * (Fillet / Small_Thick) ^ b;

end

